/* globals "1.15.0" */
import Vue from 'vue';
import Vuex from 'vuex';
import fetch from 'isomorphic-unfetch';
import marked from './utils/marked';
import highlight from './utils/highlight';
import { getFilenameByPath, isExternalLink } from './utils';
import markedRenderer from './utils/markedRenderer';
import hooks from './hooks';
import load from './utils/load';
import prismLanguages from './utils/prismLanguages';
Vue.use(Vuex);
var store = new Vuex.Store({
  state: {
    html: '',
    originalConfig: {},
    page: {
      title: null,
      headings: null
    },
    env: {},
    showSidebar: false,
    fetchingFile: true
  },
  mutations: {
    SET_HTML: function SET_HTML(state, html) {
      state.html = html;
    },
    SET_ORIGINAL_CONFIG: function SET_ORIGINAL_CONFIG(state, config) {
      state.originalConfig = config;
    },
    SET_PAGE_TITLE: function SET_PAGE_TITLE(state, title) {
      state.page.title = title;
    },
    SET_PAGE_HEADINGS: function SET_PAGE_HEADINGS(state, headings) {
      state.page.headings = headings;
    },
    TOGGLE_SIDEBAR: function TOGGLE_SIDEBAR(state, show) {
      state.showSidebar = typeof show === 'boolean' ? show : !state.showSidebar;
    },
    SET_FETCHING: function SET_FETCHING(state, fetching) {
      state.fetchingFile = fetching;
    },
    SET_ENV: function SET_ENV(state, env) {
      state.env = env;
    }
  },
  actions: {
    fetchFile: function fetchFile(_ref, _ref2) {
      return new Promise(function ($return, $error) {
        var commit, getters, dispatch, path, text, file, env, html;
        commit = _ref.commit, getters = _ref.getters, dispatch = _ref.dispatch;
        path = _ref2.path, text = _ref2.text;
        commit('TOGGLE_SIDEBAR', false);
        commit('SET_FETCHING', true);
        file = getFilenameByPath(getters.config.sourcePath, path);
        return Promise.resolve(Promise.all([!text && fetch(file).then(function (res) {
          return res.text();
        }).then(function (res) {
          text = res;
        }), dispatch('fetchPrismLanguages')])).then(function ($await_1) {
          try {
            text = hooks.process('processMarkdown', text);
            env = {
              headings: [],
              file: file
            };
            html = marked(text, {
              renderer: markedRenderer(hooks),
              highlight: highlight,
              env: env
            });
            html = hooks.process('processHTML', html);
            commit('SET_PAGE_TITLE', env.title);
            commit('SET_PAGE_HEADINGS', env.headings);
            commit('SET_FETCHING', false);
            commit('SET_ENV', env);
            commit('SET_HTML', html);
            return $return();
          } catch ($boundEx) {
            return $error($boundEx);
          }
        }, $error);
      });
    },
    fetchPrismLanguages: function fetchPrismLanguages(_ref3) {
      var getters = _ref3.getters;
      var langs = getters.config.highlight;

      if (!langs || langs.length === 0) {
        return Promise.resolve();
      }

      return load(langs.reduce(function (res, lang) {
        if (prismLanguages[lang]) {
          res = res.concat(prismLanguages[lang]);
        }

        res.push(lang);
        return res;
      }, []).filter(function (lang, i, arr) {
        // Dedupe
        return arr.indexOf(lang) === i && prismLanguages.builtin.indexOf(lang) === -1;
      }).map(function (lang) {
        return "https://unpkg.com/prismjs@" + "1.15.0" + "/components/prism-" + lang + ".js";
      }), 'prism-languages');
    }
  },
  getters: {
    target: function target(_ref4) {
      var _target = _ref4.originalConfig.target;
      if (!_target) return 'docute';
      if (_target[0] === '#') return _target.slice(1);
      return _target;
    },
    languageOverrides: function languageOverrides(_ref5) {
      var originalConfig = _ref5.originalConfig;
      // `locales` is for legacy support
      var overrides = originalConfig.overrides || originalConfig.locales;
      return overrides && Object.keys(overrides).reduce(function (res, path) {
        if (overrides[path].language) {
          res[path] = overrides[path];
        }

        return res;
      }, {});
    },
    currentLocalePath: function currentLocalePath(_ref6, _ref7) {
      var route = _ref6.route;
      var languageOverrides = _ref7.languageOverrides;

      if (languageOverrides) {
        // Is it a locale?
        var _arr = Object.keys(languageOverrides);

        for (var _i = 0; _i < _arr.length; _i++) {
          var localePath = _arr[_i];

          if (localePath !== '/') {
            var RE = new RegExp("^" + localePath);

            if (RE.test(route.path)) {
              return localePath;
            }
          }
        }
      }

      return '/';
    },
    config: function config(_ref8, _ref9) {
      var originalConfig = _ref8.originalConfig;
      var currentLocalePath = _ref9.currentLocalePath,
          languageOverrides = _ref9.languageOverrides;
      return languageOverrides ? Object.assign({}, originalConfig, languageOverrides[currentLocalePath]) : originalConfig;
    },
    homePaths: function homePaths(_, _ref10) {
      var languageOverrides = _ref10.languageOverrides;
      var localePaths = languageOverrides ? Object.keys(languageOverrides) : [];
      return localePaths.concat(['/']);
    },
    sidebarLinks: function sidebarLinks(_, _ref11) {
      var sidebar = _ref11.sidebar;
      return sidebar ? sidebar.reduce(function (res, next) {
        return res.concat(next.links);
      }, []).filter(function (item) {
        return !isExternalLink(item.link);
      }) : [];
    },
    sidebar: function sidebar(_, _ref12) {
      var config = _ref12.config;
      return config.sidebar || [];
    },
    centerContent: function centerContent(_, _ref13) {
      var config = _ref13.config;
      return config.centerContent !== false;
    }
  }
});

if (process.env.NODE_ENV === 'development') {
  window.store = store;
}

export default store;